@@ -7,29 +7,31 @@ Parameter, ComponentType and Component class definitions.
 
 from lems.base.base import LEMSBase
 from lems.base.map import Map
-from lems.base.errors import ModelError,ParseError
+from lems.base.errors import ModelError, ParseError
 
 from lems.model.dynamics import Dynamics
 from lems.model.structure import Structure
 from lems.model.simulation import Simulation
 from lems.parser.expr import ExprParser
+from xml.sax.saxutils import quoteattr
+
 
 class Parameter(LEMSBase):
     """
     Stores a parameter declaration.
     """
-    
-    def __init__(self, name, dimension, description = ''):
+
+    def __init__(self, name, dimension, description=""):
         """
         Constructor.
 
         See instance variable documentation for more details on parameters.
         """
-        
+
         self.name = name
         """ Name of the parameter.
         :type: str """
-         
+
         self.dimension = dimension
         """ Physical dimension of the parameter.
         :type: str """
@@ -37,7 +39,7 @@ class Parameter(LEMSBase):
         self.fixed = False
         """ Whether the parameter has been fixed or not.
         :type: bool """
-        
+
         self.fixed_value = None
         """ Value if fixed.
         :type: str """
@@ -59,51 +61,64 @@ class Parameter(LEMSBase):
         Exports this object into a LEMS XML object
         """
 
-        return '<{0} name="{1}" dimension="{2}"'.format('Fixed' if self.fixed else 'Parameter', self.name, self.dimension) +\
-          (' description = "{0}"'.format(self.description) if self.description else '') +\
-          '/>'
-          
-          
+        return (
+            '<{0} name="{1}" dimension="{2}"'.format(
+                "Fixed" if self.fixed else "Parameter", self.name, self.dimension
+            )
+            + (
+                ' description = "{0}"'.format(self.description)
+                if self.description
+                else ""
+            )
+            + "/>"
+        )
+
     def __str__(self):
-        return '{0}: name="{1}" dimension="{2}"'.format('Fixed' if self.fixed else 'Parameter', self.name, self.dimension) +\
-          (' description = "{0}"'.format(self.description) if self.description else '')
-          
-          
+        return '{0}: name="{1}" dimension="{2}"'.format(
+            "Fixed" if self.fixed else "Parameter", self.name, self.dimension
+        ) + (
+            ' description = "{0}"'.format(self.description) if self.description else ""
+        )
+
     def __repr__(self):
         return self.__str__()
 
+
 class Fixed(Parameter):
     """
     Stores a fixed parameter specification.
     """
-    
-    def __init__(self, parameter, value, description = ''):
+
+    def __init__(self, parameter, value, description=""):
         """
         Constructor.
 
         See instance variable documentation for more details on parameters.
         """
 
-        Parameter.__init__(self, parameter, '__dimension_inherited__', description)
-        
+        Parameter.__init__(self, parameter, "__dimension_inherited__", description)
+
         self.fixed = True
         self.fixed_value = value
-        
+
     def toxml(self):
         """
         Exports this object into a LEMS XML object
         """
 
-        return '<Fixed parameter="{0}"'.format(self.name) + ' value="{0}"'.format(self.fixed_value)+'/>'
-    
-    
-        
-class Property(LEMSBase): 
-    """ 
-    Store the specification of a property. 
-    """ 
- 
-    def __init__(self, name, dimension = None, default_value = None, description = ''): 
+        return (
+            '<Fixed parameter="{0}"'.format(self.name)
+            + ' value="{0}"'.format(self.fixed_value)
+            + "/>"
+        )
+
+
+class Property(LEMSBase):
+    """
+    Store the specification of a property.
+    """
+
+    def __init__(self, name, dimension=None, default_value=None, description=""):
         """
         Constructor.
         """
@@ -115,11 +130,11 @@ class Property(LEMSBase):
         self.dimension = dimension
         """ Physical dimensions of the property.
         :type: str """
-        
+
         self.description = description
         """ Description of the property.
         :type: str """
-        
+
         self.default_value = default_value
         """ Default value of the property.
         :type: float """
@@ -129,18 +144,24 @@ class Property(LEMSBase):
         Exports this object into a LEMS XML object
         """
 
-        return '<Property name="{0}"'.format(self.name) +\
-          (' dimension="{0}"'.format(self.dimension) if self.dimension else 'none') +\
-          (' defaultValue = "{0}"'.format(self.default_value) if self.default_value else '') +\
-          '/>'
-          
+        return (
+            '<Property name="{0}"'.format(self.name)
+            + (' dimension="{0}"'.format(self.dimension) if self.dimension else "none")
+            + (
+                ' defaultValue = "{0}"'.format(self.default_value)
+                if self.default_value
+                else ""
+            )
+            + "/>"
+        )
+
 
 class IndexParameter(LEMSBase):
     """
     Stores a parameter which is an index (integer > 0).
     """
-    
-    def __init__(self, name, description = ''):
+
+    def __init__(self, name, description=""):
         """
         Constructor.
         """
@@ -148,28 +169,34 @@ class IndexParameter(LEMSBase):
         self.name = name
         """ Name of the parameter.
         :type: str """
-        
+
         self.description = description
         """ Description of this parameter.
         :type: str """
-        
-        
+
     def toxml(self):
         """
         Exports this object into a LEMS XML object
         """
 
-        return '<IndexParameter name="{0}"'.format(self.name) + '' + \
-            (' description = "{0}"'.format(self.description) if self.description else '') +\
-            '/>'
-        
-        
-class DerivedParameter(LEMSBase): 
-    """ 
-    Store the specification of a derived parameter. 
-    """ 
- 
-    def __init__(self, name, value, dimension = None, description = ''): 
+        return (
+            '<IndexParameter name="{0}"'.format(self.name)
+            + ""
+            + (
+                ' description = "{0}"'.format(self.description)
+                if self.description
+                else ""
+            )
+            + "/>"
+        )
+
+
+class DerivedParameter(LEMSBase):
+    """
+    Store the specification of a derived parameter.
+    """
+
+    def __init__(self, name, value, dimension=None, description=""):
         """
         Constructor.
 
@@ -183,53 +210,60 @@ class DerivedParameter(LEMSBase):
         self.dimension = dimension
         """ Physical dimensions of the derived parameter.
         :type: str """
-        
+
         self.value = value
         """ Value of the derived parameter.
         :type: str """
-        
+
         self.description = description
         """ Description of the derived parameter.
         :type: str """
-        
+
         try:
             ep = ExprParser(self.value)
             self.expression_tree = ep.parse()
         except:
-            raise ParseError("Parse error when parsing value expression "
-                                 "'{0}' for derived parameter {1}",
-                                 self.value, self.name)
-        
-                             
-
+            raise ParseError(
+                "Parse error when parsing value expression "
+                "'{0}' for derived parameter {1}",
+                self.value,
+                self.name,
+            )
 
     def toxml(self):
         """
         Exports this object into a LEMS XML object
         """
 
-        return '<DerivedParameter name="{0}"'.format(self.name) +\
-          (' dimension="{0}"'.format(self.dimension) if self.dimension else '') +\
-          (' description="{0}"'.format(self.description) if self.description else '') +\
-          (' value="{0}"'.format(self.value) if self.value else '') +\
-          '/>'
+        return (
+            '<DerivedParameter name="{0}"'.format(self.name)
+            + (' dimension="{0}"'.format(self.dimension) if self.dimension else "")
+            + (
+                " description={0}".format(
+                    quoteattr(self.description) if self.description else '""'
+                )
+            )
+            + (' value="{0}"'.format(self.value) if self.value else "")
+            + "/>"
+        )
+
 
 class Constant(LEMSBase):
     """
     Stores a constant specification.
     """
-    
-    def __init__(self, name, value, dimension = None, symbol = None, description = ''):
+
+    def __init__(self, name, value, dimension=None, symbol=None, description=""):
         """
         Constructor.
 
         See instance variable documentation for more details on parameters.
         """
-        
+
         self.name = name
         """ Name of the constant.
         :type: str """
-        
+
         self.symbol = symbol
         """ Symbol of the constant.
         :type: str """
@@ -255,31 +289,37 @@ class Constant(LEMSBase):
         Exports this object into a LEMS XML object
         """
 
-        return '<Constant' +\
-          (' name = "{0}"'.format(self.name) if self.name else '') +\
-          (' symbol = "{0}"'.format(self.symbol) if self.symbol else '') +\
-          (' value = "{0}"'.format(self.value) if self.value else '') +\
-          (' dimension = "{0}"'.format(self.dimension) if self.dimension else '') +\
-          (' description = "{0}"'.format(self.description) if self.description else '') +\
-          '/>'
-        
+        return (
+            "<Constant"
+            + (' name = "{0}"'.format(self.name) if self.name else "")
+            + (' symbol = "{0}"'.format(self.symbol) if self.symbol else "")
+            + (' value = "{0}"'.format(self.value) if self.value else "")
+            + (' dimension = "{0}"'.format(self.dimension) if self.dimension else "")
+            + (
+                ' description = "{0}"'.format(self.description)
+                if self.description
+                else ""
+            )
+            + "/>"
+        )
+
 
 class Exposure(LEMSBase):
     """
     Stores a exposure specification.
     """
 
-    def __init__(self, name, dimension, description = ''):
+    def __init__(self, name, dimension, description=""):
         """
         Constructor.
 
         See instance variable documentation for more details on parameters.
         """
-        
+
         self.name = name
         """ Name of the exposure.
         :type: str """
-         
+
         self.dimension = dimension
         """ Physical dimension of the exposure.
         :type: str """
@@ -293,30 +333,37 @@ class Exposure(LEMSBase):
         Exports this object into a LEMS XML object
         """
 
-        return '<Exposure name="{0}" dimension="{1}"'.format(self.name, self.dimension) +\
-          (' description = "{0}"'.format(self.description) if self.description else '') +\
-          '/>'
+        return (
+            '<Exposure name="{0}" dimension="{1}"'.format(self.name, self.dimension)
+            + (
+                ' description = "{0}"'.format(self.description)
+                if self.description
+                else ""
+            )
+            + "/>"
+        )
+
 
 class Requirement(LEMSBase):
     """
     Stores a requirement specification.
     """
 
-    def __init__(self, name, dimension, description = ''):
+    def __init__(self, name, dimension, description=""):
         """
         Constructor.
 
         See instance variable documentation for more details on parameters.
         """
-        
+
         self.name = name
         """ Name of the requirement.
         :type: str """
-         
+
         self.dimension = dimension
         """ Physical dimension of the requirement.
         :type: str """
-        
+
         self.description = description
         """ Description of this requirement.
         :type: str """
@@ -326,17 +373,23 @@ class Requirement(LEMSBase):
         Exports this object into a LEMS XML object
         """
 
-        return '<Requirement name="{0}" dimension="{1}"'.format(self.name, self.dimension) +\
-          (' description = "{0}"'.format(self.description) if self.description else '') +\
-          '/>'
-          
-          
+        return (
+            '<Requirement name="{0}" dimension="{1}"'.format(self.name, self.dimension)
+            + (
+                ' description = "{0}"'.format(self.description)
+                if self.description
+                else ""
+            )
+            + "/>"
+        )
+
+
 class ComponentRequirement(LEMSBase):
     """
     Specifies a component that is required
     """
-    
-    def __init__(self, name, description = ''):
+
+    def __init__(self, name, description=""):
         """
         Constructor.
         """
@@ -344,40 +397,46 @@ class ComponentRequirement(LEMSBase):
         self.name = name
         """ Name of the Component required.
         :type: str """
-        
+
         self.description = description
         """ Description of this ComponentRequirement.
         :type: str """
-        
-        
+
     def toxml(self):
         """
         Exports this object into a LEMS XML object
         """
 
-        return '<ComponentRequirement name="{0}"'.format(self.name) + '' + \
-            (' description = "{0}"'.format(self.description) if self.description else '') +\
-            '/>'
-        
-          
+        return (
+            '<ComponentRequirement name="{0}"'.format(self.name)
+            + ""
+            + (
+                ' description = "{0}"'.format(self.description)
+                if self.description
+                else ""
+            )
+            + "/>"
+        )
+
+
 class InstanceRequirement(LEMSBase):
     """
     Stores an instance requirement specification.
     """
 
-    def __init__(self, name, type, description = ''):
+    def __init__(self, name, type, description=""):
         """
         Constructor.
         """
-        
+
         self.name = name
         """ Name of the instance requirement.
         :type: str """
-         
+
         self.type = type
         """ Type of the instance required.
         :type: str """
-        
+
         self.description = description
         """ Description of this InstanceRequirement.
         :type: str """
@@ -387,26 +446,33 @@ class InstanceRequirement(LEMSBase):
         Exports this object into a LEMS XML object
         """
 
-        return '<InstanceRequirement name="{0}" type="{1}"'.format(self.name, self.type) +\
-          (' description = "{0}"'.format(self.description) if self.description else '') +\
-          '/>'
+        return (
+            '<InstanceRequirement name="{0}" type="{1}"'.format(self.name, self.type)
+            + (
+                ' description = "{0}"'.format(self.description)
+                if self.description
+                else ""
+            )
+            + "/>"
+        )
+
 
 class Children(LEMSBase):
     """
     Stores children specification.
     """
-    
-    def __init__(self, name, type_, description = "", multiple = False):
+
+    def __init__(self, name, type_, description="", multiple=False):
         """
         Constructor.
 
         See instance variable documentation for more details on parameters.
         """
-        
+
         self.name = name
         """ Name of the children.
         :type: str """
-         
+
         self.type = type_
         """ Component type of the children.
         :type: str """
@@ -424,24 +490,30 @@ class Children(LEMSBase):
         Exports this object into a LEMS XML object
         """
 
-        return '<{3} name="{0}" type="{1}" description="{2}"/>'.format(self.name, self.type, self.description, 'Children' if self.multiple else 'Child')
+        return '<{3} name="{0}" type="{1}" description={2}/>'.format(
+            self.name,
+            self.type,
+            quoteattr(self.description) if self.description else '""',
+            "Children" if self.multiple else "Child",
+        )
+
 
 class Text(LEMSBase):
     """
     Stores a text entry specification.
     """
 
-    def __init__(self, name, description = ''):
+    def __init__(self, name, description=""):
         """
         Constructor.
 
         See instance variable documentation for more details on parameters.
         """
-        
+
         self.name = name
         """ Name of the text entry.
         :type: str """
-         
+
         self.description = description
         """ Description of the text entry.
         :type: str """
@@ -455,32 +527,43 @@ class Text(LEMSBase):
         Exports this object into a LEMS XML object
         """
 
-        return '<Text name="{0}"'.format(self.name) +\
-          (' description = "{0}"'.format(self.description) if self.description else '') +\
-          '/>'
-          
-          
+        return (
+            '<Text name="{0}"'.format(self.name)
+            + (
+                ' description = "{0}"'.format(self.description)
+                if self.description
+                else ""
+            )
+            + "/>"
+        )
+
     def __str__(self):
-        return 'Text, name: {0}'.format(self.name)+\
-          (', description = "{0}"'.format(self.description) if self.description else '') +\
-          (', value = "{0}"'.format(self.value) if self.value else '')
-          
-          
+        return (
+            "Text, name: {0}".format(self.name)
+            + (
+                ', description = "{0}"'.format(self.description)
+                if self.description
+                else ""
+            )
+            + (', value = "{0}"'.format(self.value) if self.value else "")
+        )
+
     def __repr__(self):
         return self.__str__()
-        
+
+
 class Link(LEMSBase):
     """
     Stores a link specification.
     """
 
-    def __init__(self, name, type_, description = ''):
+    def __init__(self, name, type_, description=""):
         """
         Constructor.
 
         See instance variable documentation for more details on parameters.
         """
-        
+
         self.name = name
         """ Name of the link entry.
         :type: str """
@@ -488,7 +571,7 @@ class Link(LEMSBase):
         self.type = type_
         """ Type of the link.
         :type: str """
-         
+
         self.description = description
         """ Description of the link.
         :type: str """
@@ -502,27 +585,33 @@ class Link(LEMSBase):
         Exports this object into a LEMS XML object
         """
 
-        return '<Link name="{0}" type="{1}"'.format(self.name, self.type) +\
-          (' description = "{0}"'.format(self.description) if self.description else '') +\
-          '/>'
+        return (
+            '<Link name="{0}" type="{1}"'.format(self.name, self.type)
+            + (
+                ' description = "{0}"'.format(self.description)
+                if self.description
+                else ""
+            )
+            + "/>"
+        )
+
 
-        
 class Path(LEMSBase):
     """
     Stores a path entry specification.
     """
 
-    def __init__(self, name, description = ''):
+    def __init__(self, name, description=""):
         """
         Constructor.
 
         See instance variable documentation for more details on parameters.
         """
-        
+
         self.name = name
         """ Name of the path entry.
         :type: str """
-         
+
         self.description = description
         """ Description of the path entry.
         :type: str """
@@ -536,30 +625,39 @@ class Path(LEMSBase):
         Exports this object into a LEMS XML object
         """
 
-        return '<Path name="{0}"'.format(self.name) +\
-          (' description = "{0}"'.format(self.description) if self.description else '') +\
-          '/>'
-        
+        return (
+            '<Path name="{0}"'.format(self.name)
+            + (
+                ' description = "{0}"'.format(self.description)
+                if self.description
+                else ""
+            )
+            + "/>"
+        )
+
+
 class EventPort(LEMSBase):
     """
     Stores an event port specification.
     """
 
-    def __init__(self, name, direction, description = ''):
+    def __init__(self, name, direction, description=""):
         """
         Constructor.
 
         See instance variable documentation for more details on parameters.
         """
-        
+
         self.name = name
         """ Name of the event port.
         :type: str """
 
         d = direction.lower()
-        if d != 'in' and d != 'out':
-            raise ModelError("Invalid direction '{0}' in event port '{1}'".format(direction, name))
-         
+        if d != "in" and d != "out":
+            raise ModelError(
+                "Invalid direction '{0}' in event port '{1}'".format(direction, name)
+            )
+
         self.direction = direction
         """ Direction - IN/OUT .
         :type: str """
@@ -573,10 +671,17 @@ class EventPort(LEMSBase):
         Exports this object into a LEMS XML object
         """
 
-        return '<EventPort name="{0}" direction="{1}"'.format(self.name, self.direction) +\
-          (' description = "{0}"'.format(self.description) if self.description else '') +\
-          '/>'
-        
+        return (
+            '<EventPort name="{0}" direction="{1}"'.format(self.name, self.direction)
+            + (
+                ' description = "{0}"'.format(self.description)
+                if self.description
+                else ""
+            )
+            + "/>"
+        )
+
+
 class ComponentReference(LEMSBase):
     """
     Stores a component reference.
@@ -610,16 +715,19 @@ class ComponentReference(LEMSBase):
         Exports this object into a LEMS XML object
         """
 
-        return '<ComponentReference name="{0}" type="{1}"'.format(self.name, self.type) + \
-          (' local = "{0}"'.format(self.local) if self.local else '') + \
-            '/>'
-        
+        return (
+            '<ComponentReference name="{0}" type="{1}"'.format(self.name, self.type)
+            + (' local = "{0}"'.format(self.local) if self.local else "")
+            + "/>"
+        )
+
+
 class Attachments(LEMSBase):
     """
     Stores an attachment type specification.
     """
 
-    def __init__(self, name, type_, description = ''):
+    def __init__(self, name, type_, description=""):
         """
         Constructor.
 
@@ -643,9 +751,16 @@ class Attachments(LEMSBase):
         Exports this object into a LEMS XML object
         """
 
-        return '<Attachments name="{0}" type="{1}"'.format(self.name, self.type) +\
-          (' description = "{0}"'.format(self.description) if self.description else '') +\
-          '/>'
+        return (
+            '<Attachments name="{0}" type="{1}"'.format(self.name, self.type)
+            + (
+                ' description = "{0}"'.format(self.description)
+                if self.description
+                else ""
+            )
+            + "/>"
+        )
+
 
 class Fat(LEMSBase):
     """
@@ -658,19 +773,19 @@ class Fat(LEMSBase):
 
         See instance variable documentation for more details on parameters.
         """
-        
+
         self.parameters = Map()
         """ Map of parameters in this component type.
         :type: Map(str -> lems.model.component.Parameter) """
-        
+
         self.properties = Map()
         """ Map of properties in this component type.
         :type: Map(str -> lems.model.component.Property) """
-        
+
         self.derived_parameters = Map()
         """ Map of derived_parameters in this component type.
         :type: Map(str -> lems.model.component.Parameter) """
-        
+
         self.index_parameters = Map()
         """ Map of index_parameters in this component type.
         :type: Map(str -> lems.model.component.IndexParameter) """
@@ -738,7 +853,7 @@ class Fat(LEMSBase):
         self.types = set()
         """ Set of compatible component types.
         :type: set(str) """
-        
+
     def add_parameter(self, parameter):
         """
         Adds a paramter to this component type.
@@ -748,8 +863,7 @@ class Fat(LEMSBase):
         """
 
         self.parameters[parameter.name] = parameter
-        
-        
+
     def add_property(self, property):
         """
         Adds a property to this component type.
@@ -759,7 +873,7 @@ class Fat(LEMSBase):
         """
 
         self.properties[property.name] = property
-        
+
     def add_derived_parameter(self, derived_parameter):
         """
         Adds a derived_parameter to this component type.
@@ -769,8 +883,7 @@ class Fat(LEMSBase):
         """
 
         self.derived_parameters[derived_parameter.name] = derived_parameter
-        
-        
+
     def add_index_parameter(self, index_parameter):
         """
         Adds an index_parameter to this component type.
@@ -781,7 +894,6 @@ class Fat(LEMSBase):
 
         self.index_parameters[index_parameter.name] = index_parameter
 
-
     def add_constant(self, constant):
         """
         Adds a paramter to this component type.
@@ -792,7 +904,6 @@ class Fat(LEMSBase):
 
         self.constants[constant.name] = constant
 
-
     def add_exposure(self, exposure):
         """
         Adds a exposure to this component type.
@@ -803,7 +914,6 @@ class Fat(LEMSBase):
 
         self.exposures[exposure.name] = exposure
 
-
     def add_requirement(self, requirement):
         """
         Adds a requirement to this component type.
@@ -814,7 +924,6 @@ class Fat(LEMSBase):
 
         self.requirements[requirement.name] = requirement
 
-
     def add_component_requirement(self, component_requirement):
         """
         Adds a component requirement to this component type.
@@ -825,7 +934,6 @@ class Fat(LEMSBase):
 
         self.component_requirements[component_requirement.name] = component_requirement
 
-
     def add_instance_requirement(self, instance_requirement):
         """
         Adds an instance requirement to this component type.
@@ -836,7 +944,6 @@ class Fat(LEMSBase):
 
         self.instance_requirements[instance_requirement.name] = instance_requirement
 
-
     def add_children(self, children):
         """
         Adds children to this component type.
@@ -947,14 +1054,15 @@ class Fat(LEMSBase):
         elif isinstance(child, Attachments):
             self.add_attachments(child)
         else:
-            raise ModelError('Unsupported child element')
+            raise ModelError("Unsupported child element")
+
 
 class ComponentType(Fat):
     """
     Stores a component type declaration.
     """
 
-    def __init__(self, name, description = '', extends = None):
+    def __init__(self, name, description="", extends=None):
         """
         Constructor.
 
@@ -962,11 +1070,11 @@ class ComponentType(Fat):
         """
 
         Fat.__init__(self)
-    
+
         self.name = name
         """ Name of the component type.
         :type: str """
-         
+
         self.extends = extends
         """ Base component type.
         :type: str """
@@ -978,87 +1086,94 @@ class ComponentType(Fat):
         self.types.add(name)
 
     def __str__(self):
-        return 'ComponentType, name: {0}'.format(self.name)
-        
+        return "ComponentType, name: {0}".format(self.name)
+
     def toxml(self):
         """
         Exports this object into a LEMS XML object
         """
 
-        xmlstr = '<ComponentType name="{0}"'.format(self.name) +\
-          (' extends="{0}"'.format(self.extends) if self.extends else '') +\
-          (' description="{0}"'.format(self.description) if self.description else '')
+        xmlstr = (
+            '<ComponentType name="{0}"'.format(self.name)
+            + (' extends="{0}"'.format(self.extends) if self.extends else "")
+            + (
+                " description={0}".format(
+                    quoteattr(self.description) if self.description else '""'
+                )
+            )
+        )
 
-        chxmlstr = ''
+        chxmlstr = ""
 
         for property in self.properties:
             chxmlstr += property.toxml()
 
         for parameter in self.parameters:
             chxmlstr += parameter.toxml()
-            
+
         for derived_parameter in self.derived_parameters:
             chxmlstr += derived_parameter.toxml()
-            
+
         for index_parameter in self.index_parameters:
             chxmlstr += index_parameter.toxml()
 
         for constant in self.constants:
             chxmlstr += constant.toxml()
-            
-        childxml = ''
-        childrenxml = ''
-        
+
+        childxml = ""
+        childrenxml = ""
+
         for children in self.children:
             if children.multiple:
                 childrenxml += children.toxml()
             else:
                 childxml += children.toxml()
-            
+
         chxmlstr += childxml
         chxmlstr += childrenxml
-            
+
         for link in self.links:
             chxmlstr += link.toxml()
-            
+
         for component_reference in self.component_references:
             chxmlstr += component_reference.toxml()
-            
+
         for attachment in self.attachments:
             chxmlstr += attachment.toxml()
-            
+
         for event_port in self.event_ports:
             chxmlstr += event_port.toxml()
-            
+
         for exposure in self.exposures:
             chxmlstr += exposure.toxml()
-            
+
         for requirement in self.requirements:
             chxmlstr += requirement.toxml()
-            
+
         for component_requirement in self.component_requirements:
             chxmlstr += component_requirement.toxml()
-            
+
         for instance_requirement in self.instance_requirements:
             chxmlstr += instance_requirement.toxml()
-            
+
         for path in self.paths:
             chxmlstr += path.toxml()
-            
+
         for text in self.texts:
             chxmlstr += text.toxml()
 
         chxmlstr += self.dynamics.toxml()
         chxmlstr += self.structure.toxml()
         chxmlstr += self.simulation.toxml()
-            
+
         if chxmlstr:
-            xmlstr += '>' + chxmlstr + '</ComponentType>'
+            xmlstr += ">" + chxmlstr + "</ComponentType>"
         else:
-            xmlstr += '/>'
+            xmlstr += "/>"
 
         return xmlstr
 
+
 class Component(LEMSBase):
     """
     Stores a component instantiation.
@@ -1088,15 +1203,16 @@ class Component(LEMSBase):
         self.children = list()
         """ List of child components.
         :type: list(lems.model.component.Component) """
-        
+
         self.parent_id = None
         """ Optional id of parent
         :type: str """
-        
 
     def __str__(self):
-        return 'Component, id: {0}, type: {1},\n   parameters: {2}\n   parent: {3}\n'.format(self.id, self.type, self.parameters, self.parent_id)
-    
+        return "Component, id: {0}, type: {1},\n   parameters: {2}\n   parent: {3}\n".format(
+            self.id, self.type, self.parameters, self.parent_id
+        )
+
     def __repr__(self):
         return self.__str__()
 
@@ -1133,19 +1249,18 @@ class Component(LEMSBase):
         if isinstance(child, Component):
             self.add_child(child)
         else:
-            raise ModelError('Unsupported child element')
-        
+            raise ModelError("Unsupported child element")
+
     def set_parent_id(self, parent_id):
         """
         Sets the id of the parent Component
-        
+
         :param parent_id: id of the parent Component
         :type parent_id: str
         """
-        
+
         self.parent_id = parent_id
-        
-        
+
     def toxml(self):
         """
         Exports this object into a LEMS XML object
@@ -1157,15 +1272,15 @@ class Component(LEMSBase):
             xmlstr += ' {0}="{1}"'.format(k, v)
 
         if self.children:
-            xmlstr += '>'
+            xmlstr += ">"
             for child in self.children:
                 xmlstr += child.toxml()
-            xmlstr += '</Component>'
+            xmlstr += "</Component>"
         else:
-            xmlstr += '/>'
+            xmlstr += "/>"
 
         return xmlstr
-    
+
 
 class FatComponent(Fat):
     """
@@ -1192,16 +1307,19 @@ class FatComponent(Fat):
         self.child_components = list()
         """ List of child components.
         :type: lems.model.component.FatComponent """
-        
+
         self.parent_id = None
         """ Optional id of parent
         :type: str """
-        
 
     def __str__(self):
-        return 'FatComponent, id: {0}, type: {1}, parent:{2}'.format(self.id, self.type, self.parent_id)+\
-          (', num children: {0}'.format(len(self.child_components)) if len(self.child_components)>0 else '')
-        
+        return "FatComponent, id: {0}, type: {1}, parent:{2}".format(
+            self.id, self.type, self.parent_id
+        ) + (
+            ", num children: {0}".format(len(self.child_components))
+            if len(self.child_components) > 0
+            else ""
+        )
 
     def add_child_component(self, child_component):
         """
@@ -1224,13 +1342,13 @@ class FatComponent(Fat):
             self.add_child_component(child)
         else:
             Fat.add(self, child)
-            
+
     def set_parent_id(self, parent_id):
         """
         Sets the id of the parent Component
-        
+
         :param parent_id: id of the parent Component
         :type parent_id: str
         """
-        
+
         self.parent_id = parent_id
